@@ -1,4 +1,8 @@
-use std::{env, path::Path, path::PathBuf, process::Command};
+use std::{
+    env, io,
+    path::{Path, PathBuf},
+    process::Command,
+};
 
 /// A helper function wrapping the flatdata generator.
 ///
@@ -30,7 +34,8 @@ use std::{env, path::Path, path::PathBuf, process::Command};
 /// ## Examples
 ///
 /// `build.rs`
-/// ``` ignore
+///
+/// ```ignore
 /// use std::env;
 ///
 /// fn main() {
@@ -39,24 +44,25 @@ use std::{env, path::Path, path::PathBuf, process::Command};
 /// ```
 ///
 /// `my_schema.rs`
-/// ``` ignore
+///
+/// ```ignore
 /// #![allow(dead_code)]
 ///
 /// include!(concat!(env!("OUT_DIR"), "/example_a/my_schema.rs"));
 ///
 /// // re-export if desired
 /// pub use my_schema::*;
+/// ```
 ///
 /// ## Development
 ///
-/// If you are working on the generator, you can make sure your `build.rs` script
-/// picks up the source by setting `FLATDATA_GENERATOR_PATH` to point to the
-/// `flatdata-generator` folder.
-/// ```
-pub fn generate<P>(schemas_path: P, out_dir: P) -> Result<(), GeneratorError>
-where
-    P: AsRef<Path>,
-{
+/// If you are working on the generator, you can make sure your `build.rs`
+/// script picks up the source by setting `FLATDATA_GENERATOR_PATH` to point to
+/// the `flatdata-generator` folder.
+pub fn generate(
+    schemas_path: impl AsRef<Path>,
+    out_dir: impl AsRef<Path>,
+) -> Result<(), GeneratorError> {
     let schemas_path = schemas_path.as_ref();
     let out_dir = out_dir.as_ref();
 
@@ -79,7 +85,7 @@ where
         path
     } else {
         eprintln!("installing flatdata-generator from PyPI");
-        PathBuf::from("flatdata-generator")
+        PathBuf::from("flatdata-generator==0.4.*")
     };
     let _ = Command::new(out_dir.join("bin/pip3"))
         .arg("install")
@@ -111,7 +117,7 @@ where
         );
 
         std::fs::create_dir_all(result.parent().unwrap())?;
-        let _ = std::process::Command::new(out_dir.join("bin/flatdata-generator"))
+        let exit_code = Command::new(out_dir.join("bin/flatdata-generator"))
             .arg("-g")
             .arg("rust")
             .arg("-s")
@@ -121,10 +127,25 @@ where
             .spawn()
             .map_err(|e| GeneratorError::Failure {
                 schema: entry.path().into(),
-                destination: result,
+                destination: result.clone(),
                 error: e,
             })?
-            .wait()?;
+            .wait()?
+            .code();
+
+        if exit_code != Some(0) {
+            return Err(GeneratorError::Failure {
+                schema: entry.path().into(),
+                destination: result,
+                error: io::Error::new(
+                    io::ErrorKind::Other,
+                    match exit_code {
+                        Some(code) => format!("Failed to run the generator, exit code {}", code),
+                        None => "Failed to run the generator, no exit code".into(),
+                    },
+                ),
+            });
+        }
 
         println!("cargo:rerun-if-changed={}", entry.path().display());
     }
