@@ -1,5 +1,4 @@
 use crate::{
-    archive::ArchiveBuilder,
     error::ResourceStorageError,
     memory::{SizeType, PADDING_SIZE},
     multivector::MultiVector,
@@ -13,9 +12,8 @@ use std::{
     io::{self, Seek, Write},
     mem,
     ops::DerefMut,
-    ptr,
     rc::Rc,
-    slice, str,
+    str,
 };
 
 use diff;
@@ -146,7 +144,7 @@ pub fn create_external_vector<'a, T>(
     schema: &str,
 ) -> io::Result<ExternalVector<'a, T>>
 where
-    T: for<'b> Struct<'b>,
+    T: Struct,
 {
     // write schema
     let schema_name = format!("{}.schema", resource_name);
@@ -203,10 +201,12 @@ where
 ///
 /// [`AlreadyExists`]: https://doc.rust-lang.org/std/io/enum.ErrorKind.html#AlreadyExists.v
 #[doc(hidden)]
-pub fn create_archive<T: ArchiveBuilder>(
+pub fn create_archive(
+    name: &str,
+    schema: &str,
     storage: &Rc<dyn ResourceStorage>,
 ) -> Result<(), ResourceStorageError> {
-    let signature_name = format!("{}.archive", T::NAME);
+    let signature_name = format!("{}.archive", name);
     {
         // existing archive yields an error
         if storage.exists(&signature_name) {
@@ -219,52 +219,12 @@ pub fn create_archive<T: ArchiveBuilder>(
     {
         // write empty signature and schema
         storage
-            .write(&signature_name, T::SCHEMA, &[])
+            .write(&signature_name, schema, &[])
             .map_err(|e| ResourceStorageError::from_io_error(e, signature_name))?;
     }
     Ok(())
 }
 
-/// Describes a chunk of memory
-#[doc(hidden)]
-#[derive(Debug, Clone)]
-pub struct MemoryDescriptor {
-    ptr: *const u8,
-    size: usize,
-}
-
-impl Default for MemoryDescriptor {
-    #[inline]
-    fn default() -> MemoryDescriptor {
-        MemoryDescriptor {
-            ptr: ptr::null(),
-            size: 0,
-        }
-    }
-}
-
-/// Describes a contiguous constant chunk of memory without tracking lifetime
-/// Used to enabling caching files retrieved from ResourceStorage without
-/// Sibling-Borrow woes
-impl MemoryDescriptor {
-    /// Creates a new memory descriptor from a pointer and its size in bytes.
-    #[inline]
-    pub fn new(data: &[u8]) -> MemoryDescriptor {
-        MemoryDescriptor {
-            ptr: data.as_ptr(),
-            size: data.len(),
-        }
-    }
-
-    /// Converts back to bytes (lifetime corresponds to the descriptor's)
-    /// Inherently unsafe, since there is no guarantee that the original buffer
-    /// is still alive
-    #[inline]
-    pub unsafe fn as_bytes(&self) -> &[u8] {
-        slice::from_raw_parts(self.ptr, self.size)
-    }
-}
-
 /// A handle to a resource for writing to it.
 ///
 /// Wraps a `Stream` returned by [`create_output_stream`].
@@ -333,7 +293,6 @@ impl<'a> ResourceHandle<'a> {
 
     fn finalize(&mut self) -> Result<(), ResourceStorageError> {
         assert!(!self.finalized);
-        // Mark as finalized even in case of failure, otherwise Drop would complain
         self.finalized = true;
 
         let resource_name = self.name.clone();
@@ -353,14 +312,6 @@ impl<'a> ResourceHandle<'a> {
     }
 }
 
-impl<'a> Drop for ResourceHandle<'a> {
-    fn drop(&mut self) {
-        if !self.finalized && !std::thread::panicking() {
-            panic!("Resource not closed: {}", self.name);
-        }
-    }
-}
-
 impl<'a> fmt::Debug for ResourceHandle<'a> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(
@@ -414,30 +365,6 @@ mod test {
     use super::*;
     use crate::memstorage::MemoryResourceStorage;
 
-    #[test]
-    #[should_panic]
-    fn test_panic_on_drop() {
-        let storage = MemoryResourceStorage::new("/root/extvec");
-
-        let stream = storage
-            .create_output_stream("/root/extvec/blubb.schema")
-            .unwrap();
-        stream
-            .borrow_mut()
-            .write_all("myschema".as_bytes())
-            .unwrap();
-
-        let stream = storage.create_output_stream("/root/extvec/blubb").unwrap();
-        let _h = ResourceHandle::try_new(
-            &*storage,
-            "/root/extvec/blubb".into(),
-            "myschema".into(),
-            stream,
-        )
-        .unwrap();
-        // leak h without closing it -> should panic
-    }
-
     #[test]
     fn test_not_panic_on_close() -> Result<(), ResourceStorageError> {
         let storage = MemoryResourceStorage::new("/root/extvec");
